﻿using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace KB9331_CompositeChart_WinFormsApp1
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ultraChart1.ColorModel.ModelStyle = ColorModels.CustomLinear;
            Color[] ChartColors;
            ChartColors = new Color[] { Color.Red, Color.Orange, Color.Yellow, Color.Green, Color.Blue, Color.Indigo, Color.Violet };
            ultraChart1.ColorModel.CustomPalette = ChartColors;

            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea myChartArea = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(myChartArea);

            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.DataType = AxisDataType.String;
            axisX.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";

            // Y軸のExtentを設定する。
            axisY.Extent = 20;

            myChartArea.Axes.Add(axisX);
            myChartArea.Axes.Add(axisY);

            NumericSeries seriesA = this.GetNumericSeriesBound();
            NumericSeries seriesB = this.GetNumericSeriesUnBound();
            this.ultraChart1.CompositeChart.Series.Add(seriesA);
            this.ultraChart1.CompositeChart.Series.Add(seriesB);

            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ColumnChart;
            myColumnLayer.ChartArea = myChartArea;
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            myColumnLayer.Series.Add(seriesA);
            myColumnLayer.Series.Add(seriesB);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);


            AxisItem axisX2 = new AxisItem();
            axisX2.OrientationType = AxisNumber.X2_Axis;
            axisX2.DataType = AxisDataType.Numeric;
            axisX2.Labels.ItemFormatString = "";
            axisX2.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX2.Extent = 40;
            myChartArea.Axes.Add(axisX2);

            XYSeries seriesC = this.GetXYSeriesBound();
            XYSeries seriesD = this.GetXYSeriesUnBound();
            this.ultraChart1.CompositeChart.Series.Add(seriesC);
            this.ultraChart1.CompositeChart.Series.Add(seriesD);
            // 連続した色をカスタマイズします。
            seriesC.PEs.Add(new PaintElement(Color.Green));
            seriesD.PEs.Add(new PaintElement(Color.Blue));

            ChartLayerAppearance myScatterLayer = new ChartLayerAppearance();
            myScatterLayer.ChartType = ChartType.ScatterChart;
            ((ScatterChartAppearance)myScatterLayer.ChartTypeAppearance).ConnectWithLines = true;
            myScatterLayer.ChartArea = myChartArea;
            myScatterLayer.AxisX = axisX2;
            myScatterLayer.AxisY = axisY;
            myScatterLayer.Series.Add(seriesC);
            myScatterLayer.Series.Add(seriesD);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myScatterLayer);
        }


        private DataTable GetData()
        {
            DataTable table = new DataTable();
            table.Columns.Add("Label Column", typeof(string));
            table.Columns.Add("Value Column", typeof(double));
            table.Columns.Add("Another Value Column", typeof(double));
            table.Rows.Add(new object[] { "Point A", 1.0, 3.0 });
            table.Rows.Add(new object[] { "Point B", 2.0, 2.0 });
            table.Rows.Add(new object[] { "Point C", 3.0, 1.0 });
            table.Rows.Add(new object[] { "Point D", 4.0, 2.0 });
            table.Rows.Add(new object[] { "Point E", 5.0, 3.0 });
            return table;
        }

        private NumericSeries GetNumericSeriesBound()
        {
            NumericSeries series = new NumericSeries();
            series.Label = "Series A";
            // このコードは外部データソースからデータセットを格納します
            DataTable table = this.GetData();
            series.Data.DataSource = table;
            series.Data.LabelColumn = "Label Column";
            series.Data.ValueColumn = "Value Column";
            return series;
        }

        private NumericSeries GetNumericSeriesUnBound()
        {
            NumericSeries series = new NumericSeries();
            series.Label = "Series B";
            // このコードは非連結データを使用してデータセットを格納します
            series.Points.Add(new NumericDataPoint(5.0, "Point A", false));
            series.Points.Add(new NumericDataPoint(4.0, "Point B", false));
            series.Points.Add(new NumericDataPoint(3.0, "Point C", false));
            series.Points.Add(new NumericDataPoint(2.0, "Point D", false));
            series.Points.Add(new NumericDataPoint(1.0, "Point E", false));
            return series;
        }

        private XYSeries GetXYSeriesBound()
        {
            XYSeries series = new XYSeries();
            series.Label = "Series C";
            // このコードは外部データソースからデータセットを格納します
            DataTable table = this.GetData();
            series.Data.DataSource = table;
            series.Data.LabelColumn = "Label Column";
            series.Data.ValueXColumn = "Value Column";
            series.Data.ValueYColumn = "Another Value Column";
            return series;
        }
        private XYSeries GetXYSeriesUnBound()
        {
            XYSeries series = new XYSeries();
            series.Label = "Series D";
            // このコードは非連結データを使用してデータセットを格納します
            series.Points.Add(new XYDataPoint(1.0, 1.0, "Point A", false));
            series.Points.Add(new XYDataPoint(2.0, 2.0, "Point B", false));
            series.Points.Add(new XYDataPoint(3.0, 3.0, "Point C", false));
            series.Points.Add(new XYDataPoint(4.0, 4.0, "Point D", false));
            series.Points.Add(new XYDataPoint(5.0, 5.0, "Point E", false));
            return series;
        }
    }
}
